@@ -23,7 +23,7 @@ import os
 import sys
 
 
-VERSION = "0.38.3"
+VERSION = "0.38.4"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
 if sys.platform.startswith("win"):
@@ -40,7 +40,7 @@ if sys.platform.startswith("win"):
 else:
     IS_WIN_OS = False
     SZA_PATH = "7za"
-    TMP_FOLDER = '/tmp/ct_tmp/'
+    TMP_FOLDER = os.environ['TEMP'] if 'TEMP' in os.environ else '/tmp/ct_tmp/'
     MODULES_PATH = os.path.dirname(os.path.realpath(__file__))
     CONFIG_DIR = os.path.join(os.path.expanduser('~'), '.config', 'cherrytree')
     if SHARE_PATH == os.path.dirname(MODULES_PATH):
@@ -65,7 +65,7 @@ XDG_CURRENT_DESKTOP = 'XDG_CURRENT_DESKTOP'
 HAS_SYSTRAY = not (XDG_CURRENT_DESKTOP in os.environ and os.environ[XDG_CURRENT_DESKTOP] == "Unity")
 
 AVAILABLE_LANGS = ['default', 'cs', 'de', 'el', 'en', 'es', 'fi', 'fr', 'hy', 'it', 'ja', 'lt', 'nl', 'pl', 'pt_BR', 'ru', 'sl', 'tr', 'uk', 'zh_CN']
-COLOR_48_LINK_WEBS = "#00004444ffff"
+COLOR_48_LINK_WEBS = "#00008989ffff"
 COLOR_48_LINK_NODE = "#071c838e071c"
 COLOR_48_LINK_FILE = "#8b8b69691414"
 COLOR_48_LINK_FOLD = "#7f7f7f7f7f7f"
